@@ -38,7 +38,7 @@ function(L, R, group,
     rho=NULL,
     alternative= c("two.sided", "less", "greater"),   
     icFIT=NULL,
-    initfit="initcomputeMLE", 
+    initfit=NULL, 
     icontrol=icfitControl(),
     exact=NULL,
     method=NULL,
